-- Table: "Paises"

DROP TABLE "Paises" cascade;

CREATE TABLE "Paises"
(
  "IdPais" serial CONSTRAINT "PK_ID_PAIS" PRIMARY KEY USING INDEX TABLESPACE "TFG_BBDD_IDX" NOT NULL, -- Identificador del pais
  "NombrePais" character(50) -- Nombre del pais
  )
WITH (
  OIDS=FALSE
)
TABLESPACE "TFG_BBDD_DATOS";
ALTER TABLE "Paises"
  OWNER TO postgres;
COMMENT ON TABLE "Paises"
  IS 'Tabla de paises';
COMMENT ON COLUMN "Paises"."IdPais" IS 'Identificador del pais';
COMMENT ON COLUMN "Paises"."NombrePais" IS 'Nombre del pais';

-- Table: "Ciudades"

DROP TABLE "Ciudades" cascade;

CREATE TABLE "Ciudades"
(
  "IdCiudad" serial CONSTRAINT "PK_IdCiudad" PRIMARY KEY USING INDEX TABLESPACE "TFG_BBDD_IDX" NOT NULL, -- Identificador de la ciudad
  "NombreCiudad" character(50) -- Nombre de la ciudad
  )
WITH (
  OIDS=FALSE
)
TABLESPACE "TFG_BBDD_DATOS";
ALTER TABLE "Ciudades"
  OWNER TO postgres;
COMMENT ON TABLE "Ciudades"
  IS 'Tabla de ciudades';
COMMENT ON COLUMN "Ciudades"."IdCiudad" IS 'Identificador de la ciudad';
COMMENT ON COLUMN "Ciudades"."NombreCiudad" IS 'Nombre de la ciudad';

-- Table: "Contadores"

DROP TABLE "Contadores" cascade;

CREATE TABLE "Contadores"
(
  "IdContador" serial CONSTRAINT "PK_IdContador" PRIMARY KEY USING INDEX TABLESPACE "TFG_BBDD_IDX" NOT NULL, -- Identificador del contador
  "Modelo" character(50), -- Modelo del contador
  "CodigoContratoAsociado" integer NOT NULL, -- Codigo del contrato asociado
  "Potencia" integer, -- Potencia en Kilowatios
  "FechaUltimaInspeccion" date NOT NULL, -- Fecha última inspección
  "FechaInstalacion" date NOT NULL, -- Fecha de instalación
  "NumeroSerie" integer NOT NULL, -- Número de Serie del contador
  CONSTRAINT "UN_CodigoContratoAsociado" UNIQUE ("CodigoContratoAsociado" )
  USING INDEX TABLESPACE "TFG_BBDD_IDX",
  CONSTRAINT "UN_NumeroSerie" UNIQUE ("NumeroSerie" )
  USING INDEX TABLESPACE "TFG_BBDD_IDX"
)
WITH (
  OIDS=FALSE
)
TABLESPACE "TFG_BBDD_DATOS";
ALTER TABLE "Contadores"
  OWNER TO postgres;
COMMENT ON TABLE "Contadores"
  IS 'Tabla de contadores';
COMMENT ON COLUMN "Contadores"."IdContador" IS 'Identificador del contador';
COMMENT ON COLUMN "Contadores"."Modelo" IS 'Modelo del contador';
COMMENT ON COLUMN "Contadores"."CodigoContratoAsociado" IS 'Codigo del contrato asociado';
COMMENT ON COLUMN "Contadores"."Potencia" IS 'Potencia en Kilowatios';
COMMENT ON COLUMN "Contadores"."FechaUltimaInspeccion" IS 'Fecha última inspección';
COMMENT ON COLUMN "Contadores"."FechaInstalacion" IS 'Fecha de instalación';
COMMENT ON COLUMN "Contadores"."NumeroSerie" IS 'Número de Serie del contador';


-- Table: "PrecioEnergia"

DROP TABLE "PrecioEnergia" cascade;

CREATE TABLE "PrecioEnergia"
(
  "Fecha" date NOT NULL, -- Fecha Precio Energia
  "Hora" time(6) with time zone NOT NULL, -- Hora Precio Energia
  "Pais" character(30) NOT NULL, -- Pais Precio Energia
  "PrecioKw" real, -- Precio en Kilowatios del precio de la energia
  CONSTRAINT "PK_PrecioEnergia" PRIMARY KEY ("Fecha" , "Hora" , "Pais" )
  USING INDEX TABLESPACE "TFG_BBDD_IDX"
)
WITH (
  OIDS=FALSE
)
TABLESPACE "TFG_BBDD_DATOS";
ALTER TABLE "PrecioEnergia"
  OWNER TO postgres;
COMMENT ON TABLE "PrecioEnergia"
  IS 'Tabla Precios Energia';
COMMENT ON COLUMN "PrecioEnergia"."Fecha" IS 'Fecha Precio Energia';
COMMENT ON COLUMN "PrecioEnergia"."Hora" IS 'Hora Precio Energia';
COMMENT ON COLUMN "PrecioEnergia"."Pais" IS 'Pais Precio Energia';
COMMENT ON COLUMN "PrecioEnergia"."PrecioKw" IS 'Precio en Kilowatios del precio de la energia';

-- Table: "LogConexion"

DROP TABLE "LogConexion" cascade;

CREATE TABLE "LogConexion"
(
  "IdLogConexion" serial CONSTRAINT "PK_IdLogConexion" PRIMARY KEY USING INDEX TABLESPACE "TFG_BBDD_IDX" NOT NULL, -- Identificador del log de conexion
  "FechaConexion" date NOT NULL, -- Fecha de conexion del log
  "HoraConexion" time(6) with time zone NOT NULL, -- Hora del log de conexion
  "NumeroSerieContador" integer NOT NULL, -- Numero de Serie del contador
  "ConsumoContador" real, -- Consumo del contador
  "ResultatLectura" character(2) NOT NULL, -- Resultado de la lectura ('OK','KO')
  CONSTRAINT "FK_NumeroSerieContador" FOREIGN KEY ("NumeroSerieContador")
      REFERENCES "Contadores" ("NumeroSerie") MATCH SIMPLE
      ON UPDATE NO ACTION ON DELETE NO ACTION
)
WITH (
  OIDS=FALSE
)
TABLESPACE "TFG_BBDD_DATOS";
ALTER TABLE "LogConexion"
  OWNER TO postgres;
COMMENT ON TABLE "LogConexion"
  IS 'Tabla Log Conexion';
COMMENT ON COLUMN "LogConexion"."IdLogConexion" IS 'Identificador del log de conexion';
COMMENT ON COLUMN "LogConexion"."FechaConexion" IS 'Fecha de conexion del log';
COMMENT ON COLUMN "LogConexion"."HoraConexion" IS 'Hora del log de conexion';
COMMENT ON COLUMN "LogConexion"."NumeroSerieContador" IS 'Numero de Serie del contador';
COMMENT ON COLUMN "LogConexion"."ConsumoContador" IS 'Consumo del contador';
COMMENT ON COLUMN "LogConexion"."ResultatLectura" IS 'Resultado de la lectura (''OK'',''KO'')';

-- Table: "Empresas"

DROP TABLE "Empresas" cascade;

CREATE TABLE "Empresas"
(
  "IdEmpresa" serial CONSTRAINT "PK_Empresa" PRIMARY KEY USING INDEX TABLESPACE "TFG_BBDD_IDX" NOT NULL, -- Identificador de la empresa
  "NIF" character(12) NOT NULL, -- Identificador fiscal de la empresa
  "Nombre" character(50), -- Nombre de la empresa
  "DomicilioFiscal" character(50), -- Domicilio fiscal de la empresa
  "Pais" character(50) -- Pais
 )
WITH (
  OIDS=FALSE
)
TABLESPACE "TFG_BBDD_DATOS";
ALTER TABLE "Empresas"
  OWNER TO postgres;
COMMENT ON TABLE "Empresas"
  IS 'Tabla de empresas';
COMMENT ON COLUMN "Empresas"."IdEmpresa" IS 'Identificador de la empresa';
COMMENT ON COLUMN "Empresas"."NIF" IS 'Identificador fiscal de la empresa';
COMMENT ON COLUMN "Empresas"."Nombre" IS 'Nombre de la empresa';
COMMENT ON COLUMN "Empresas"."DomicilioFiscal" IS 'Domicilio fiscal de la empresa';
COMMENT ON COLUMN "Empresas"."Pais" IS 'Pais ';


-- Table: "Consumidores"

DROP TABLE "Consumidores" cascade;

CREATE TABLE "Consumidores"
(
  "IdConsumidor" serial CONSTRAINT "PK_Consumidores" PRIMARY KEY USING INDEX TABLESPACE "TFG_BBDD_IDX" NOT NULL, -- Identificador del consumidor
  "NIF" character(12) NOT NULL, -- Identificador del consumidor
  "Direccion" character(50), -- Dirección del consumidor
  "Ciudad" character(50), -- Ciudad del consumidor
  "Pais" character(50), -- Pais del consumidor
  "CodigoContratoContador" integer NOT NULL, -- Codigo del contrato del contador
  "DatosBancarios" character(20), -- Datos bancarios del consumidor
  "CodigoEmpresaSubministradora" integer NOT NULL, -- Codigo de la empresa subministradora
  "CodigoPais" integer NOT NULL, -- Codigo del pais
  CONSTRAINT "FK_Consumidores" FOREIGN KEY ("CodigoContratoContador")
      REFERENCES "Contadores" ("CodigoContratoAsociado") MATCH SIMPLE
      ON UPDATE NO ACTION ON DELETE NO ACTION,
  CONSTRAINT "FK_EmpresaSubministradora" FOREIGN KEY ("CodigoEmpresaSubministradora")
      REFERENCES "Empresas" ("IdEmpresa") MATCH SIMPLE
      ON UPDATE NO ACTION ON DELETE NO ACTION,
  CONSTRAINT "FK_Pais" FOREIGN KEY ("CodigoPais")
      REFERENCES "Paises" ("IdPais") MATCH SIMPLE
      ON UPDATE NO ACTION ON DELETE NO ACTION
)
WITH (
  OIDS=FALSE
)
TABLESPACE "TFG_BBDD_DATOS";
ALTER TABLE "Consumidores"
  OWNER TO postgres;
COMMENT ON TABLE "Consumidores"
  IS 'Tabla de consumidores';
COMMENT ON COLUMN "Consumidores"."IdConsumidor" IS 'Identificador del consumidor';
COMMENT ON COLUMN "Consumidores"."NIF" IS 'Identificador del consumidor';
COMMENT ON COLUMN "Consumidores"."Direccion" IS 'Dirección del consumidor';
COMMENT ON COLUMN "Consumidores"."Ciudad" IS 'Ciudad del consumidor';
COMMENT ON COLUMN "Consumidores"."Pais" IS 'Pais del consumidor';
COMMENT ON COLUMN "Consumidores"."CodigoContratoContador" IS 'Codigo del contrato del contador';
COMMENT ON COLUMN "Consumidores"."DatosBancarios" IS 'Datos bancarios del consumidor';
COMMENT ON COLUMN "Consumidores"."CodigoEmpresaSubministradora" IS 'Codigo de la empresa subministradora';
COMMENT ON COLUMN "Consumidores"."CodigoPais" IS 'Codigo del pais';

